/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.colors;

/**
 * All modern browsers support the following 140 color names.
 * 
 * @author Andrea "Stock" Stocchero
 * 
 * @see <a href="https://www.w3schools.com/colors/colors_names.asp">HTML Color names</a>
 *
 */
public enum HtmlColor implements IsEnumeratedColor
{
	/**
	 * HTML color name "<b>aliceBlue</b>" - <span style="background-color:#F0F8FF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ALICE_BLUE("#F0F8FF", "aliceBlue"),

	/**
	 * HTML color name "<b>antiqueWhite</b>" - <span style="background-color:#FAEBD7; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ANTIQUE_WHITE("#FAEBD7", "antiqueWhite"),

	/**
	 * HTML color name "<b>aqua</b>" - <span style="background-color:#00FFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AQUA("#00FFFF", "aqua"),

	/**
	 * HTML color name "<b>aquamarine</b>" - <span style="background-color:#7FFFD4; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AQUAMARINE("#7FFFD4", "aquamarine"),

	/**
	 * HTML color name "<b>azure</b>" - <span style="background-color:#F0FFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AZURE("#F0FFFF", "azure"),

	/**
	 * HTML color name "<b>beige</b>" - <span style="background-color:#F5F5DC; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BEIGE("#F5F5DC", "beige"),

	/**
	 * HTML color name "<b>bisque</b>" - <span style="background-color:#FFE4C4; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BISQUE("#FFE4C4", "bisque"),

	/**
	 * HTML color name "<b>black</b>" - <span style="background-color:#000000; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLACK("#000000", "black"),

	/**
	 * HTML color name "<b>blanchedAlmond</b>" - <span style="background-color:#FFEBCD; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLANCHED_ALMOND("#FFEBCD", "blanchedAlmond"),

	/**
	 * HTML color name "<b>blue</b>" - <span style="background-color:#0000FF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE("#0000FF", "blue"),

	/**
	 * HTML color name "<b>blueViolet</b>" - <span style="background-color:#8A2BE2; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE_VIOLET("#8A2BE2", "blueViolet"),

	/**
	 * HTML color name "<b>brown</b>" - <span style="background-color:#A52A2A; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BROWN("#A52A2A", "brown"),

	/**
	 * HTML color name "<b>burlyWood</b>" - <span style="background-color:#DEB887; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BURLY_WOOD("#DEB887", "burlyWood"),

	/**
	 * HTML color name "<b>cadetBlue</b>" - <span style="background-color:#5F9EA0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CADET_BLUE("#5F9EA0", "cadetBlue"),

	/**
	 * HTML color name "<b>chartreuse</b>" - <span style="background-color:#7FFF00; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHARTREUSE("#7FFF00", "chartreuse"),

	/**
	 * HTML color name "<b>chocolate</b>" - <span style="background-color:#D2691E; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHOCOLATE("#D2691E", "chocolate"),

	/**
	 * HTML color name "<b>coral</b>" - <span style="background-color:#FF7F50; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CORAL("#FF7F50", "coral"),

	/**
	 * HTML color name "<b>cornflowerBlue</b>" - <span style="background-color:#6495ED; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CORNFLOWER_BLUE("#6495ED", "cornflowerBlue"),

	/**
	 * HTML color name "<b>cornsilk</b>" - <span style="background-color:#FFF8DC; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CORNSILK("#FFF8DC", "cornsilk"),

	/**
	 * HTML color name "<b>crimson</b>" - <span style="background-color:#DC143C; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CRIMSON("#DC143C", "crimson"),

	/**
	 * HTML color name "<b>cyan</b>" - <span style="background-color:#00FFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CYAN("#00FFFF", "cyan"),

	/**
	 * HTML color name "<b>darkBlue</b>" - <span style="background-color:#00008B; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_BLUE("#00008B", "darkBlue"),

	/**
	 * HTML color name "<b>darkCyan</b>" - <span style="background-color:#008B8B; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_CYAN("#008B8B", "darkCyan"),

	/**
	 * HTML color name "<b>darkGoldenRod</b>" - <span style="background-color:#B8860B; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_GOLDEN_ROD("#B8860B", "darkGoldenRod"),

	/**
	 * HTML color name "<b>darkGray</b>" - <span style="background-color:#A9A9A9; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_GRAY("#A9A9A9", "darkGray"),

	/**
	 * HTML color name "<b>darkGrey</b>" - <span style="background-color:#A9A9A9; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_GREY("#A9A9A9", "darkGrey"),

	/**
	 * HTML color name "<b>darkGreen</b>" - <span style="background-color:#006400; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_GREEN("#006400", "darkGreen"),

	/**
	 * HTML color name "<b>darkKhaki</b>" - <span style="background-color:#BDB76B; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_KHAKI("#BDB76B", "darkKhaki"),

	/**
	 * HTML color name "<b>darkMagenta</b>" - <span style="background-color:#8B008B; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_MAGENTA("#8B008B", "darkMagenta"),

	/**
	 * HTML color name "<b>darkOliveGreen</b>" - <span style="background-color:#556B2F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_OLIVE_GREEN("#556B2F", "darkOliveGreen"),

	/**
	 * HTML color name "<b>darkOrange</b>" - <span style="background-color:#FF8C00; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_ORANGE("#FF8C00", "darkOrange"),

	/**
	 * HTML color name "<b>darkOrchid</b>" - <span style="background-color:#9932CC; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_ORCHID("#9932CC", "darkOrchid"),

	/**
	 * HTML color name "<b>darkRed</b>" - <span style="background-color:#8B0000; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_RED("#8B0000", "darkRed"),

	/**
	 * HTML color name "<b>darkSalmon</b>" - <span style="background-color:#E9967A; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_SALMON("#E9967A", "darkSalmon"),

	/**
	 * HTML color name "<b>darkSeaGreen</b>" - <span style="background-color:#8FBC8F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_SEA_GREEN("#8FBC8F", "darkSeaGreen"),

	/**
	 * HTML color name "<b>darkSlateBlue</b>" - <span style="background-color:#483D8B; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_SLATE_BLUE("#483D8B", "darkSlateBlue"),

	/**
	 * HTML color name "<b>darkSlateGray</b>" - <span style="background-color:#2F4F4F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_SLATE_GRAY("#2F4F4F", "darkSlateGray"),

	/**
	 * HTML color name "<b>darkSlateGrey</b>" - <span style="background-color:#2F4F4F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_SLATE_GREY("#2F4F4F", "darkSlateGrey"),

	/**
	 * HTML color name "<b>darkTurquoise</b>" - <span style="background-color:#00CED1; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_TURQUOISE("#00CED1", "darkTurquoise"),

	/**
	 * HTML color name "<b>darkViolet</b>" - <span style="background-color:#9400D3; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_VIOLET("#9400D3", "darkViolet"),

	/**
	 * HTML color name "<b>deepPink</b>" - <span style="background-color:#FF1493; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DEEP_PINK("#FF1493", "deepPink"),

	/**
	 * HTML color name "<b>deepSkyBlue</b>" - <span style="background-color:#00BFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DEEP_SKY_BLUE("#00BFFF", "deepSkyBlue"),

	/**
	 * HTML color name "<b>dimGray</b>" - <span style="background-color:#696969; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DIM_GRAY("#696969", "dimGray"),

	/**
	 * HTML color name "<b>dimGrey</b>" - <span style="background-color:#696969; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DIM_GREY("#696969", "dimGrey"),

	/**
	 * HTML color name "<b>dodgerBlue</b>" - <span style="background-color:#1E90FF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DODGER_BLUE("#1E90FF", "dodgerBlue"),

	/**
	 * HTML color name "<b>fireBrick</b>" - <span style="background-color:#B22222; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FIRE_BRICK("#B22222", "fireBrick"),

	/**
	 * HTML color name "<b>floralWhite</b>" - <span style="background-color:#FFFAF0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FLORAL_WHITE("#FFFAF0", "floralWhite"),

	/**
	 * HTML color name "<b>forestGreen</b>" - <span style="background-color:#228B22; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FOREST_GREEN("#228B22", "forestGreen"),

	/**
	 * HTML color name "<b>fuchsia</b>" - <span style="background-color:#FF00FF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FUCHSIA("#FF00FF", "fuchsia"),

	/**
	 * HTML color name "<b>gainsboro</b>" - <span style="background-color:#DCDCDC; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GAINSBORO("#DCDCDC", "gainsboro"),

	/**
	 * HTML color name "<b>ghostWhite</b>" - <span style="background-color:#F8F8FF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GHOST_WHITE("#F8F8FF", "ghostWhite"),

	/**
	 * HTML color name "<b>gold</b>" - <span style="background-color:#FFD700; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GOLD("#FFD700", "gold"),

	/**
	 * HTML color name "<b>goldenRod</b>" - <span style="background-color:#DAA520; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GOLDEN_ROD("#DAA520", "goldenRod"),

	/**
	 * HTML color name "<b>gray</b>" - <span style="background-color:#808080; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GRAY("#808080", "gray"),

	/**
	 * HTML color name "<b>grey</b>" - <span style="background-color:#808080; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GREY("#808080", "grey"),

	/**
	 * HTML color name "<b>green</b>" - <span style="background-color:#008000; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GREEN("#008000", "green"),

	/**
	 * HTML color name "<b>greenYellow</b>" - <span style="background-color:#ADFF2F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GREEN_YELLOW("#ADFF2F", "greenYellow"),

	/**
	 * HTML color name "<b>honeyDew</b>" - <span style="background-color:#F0FFF0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HONEY_DEW("#F0FFF0", "honeyDew"),

	/**
	 * HTML color name "<b>hotPink</b>" - <span style="background-color:#FF69B4; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HOT_PINK("#FF69B4", "hotPink"),

	/**
	 * HTML color name "<b>indianRed</b>" - <span style="background-color:#CD5C5C; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	INDIAN_RED("#CD5C5C", "indianRed"),

	/**
	 * HTML color name "<b>indigo</b>" - <span style="background-color:#4B0082; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	INDIGO("#4B0082", "indigo"),

	/**
	 * HTML color name "<b>ivory</b>" - <span style="background-color:#FFFFF0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	IVORY("#FFFFF0", "ivory"),

	/**
	 * HTML color name "<b>khaki</b>" - <span style="background-color:#F0E68C; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KHAKI("#F0E68C", "khaki"),

	/**
	 * HTML color name "<b>lavender</b>" - <span style="background-color:#E6E6FA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LAVENDER("#E6E6FA", "lavender"),

	/**
	 * HTML color name "<b>lavenderBlush</b>" - <span style="background-color:#FFF0F5; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LAVENDER_BLUSH("#FFF0F5", "lavenderBlush"),

	/**
	 * HTML color name "<b>lawnGreen</b>" - <span style="background-color:#7CFC00; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LAWN_GREEN("#7CFC00", "lawnGreen"),

	/**
	 * HTML color name "<b>lemonChiffon</b>" - <span style="background-color:#FFFACD; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LEMON_CHIFFON("#FFFACD", "lemonChiffon"),

	/**
	 * HTML color name "<b>lightBlue</b>" - <span style="background-color:#ADD8E6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_BLUE("#ADD8E6", "lightBlue"),

	/**
	 * HTML color name "<b>lightCoral</b>" - <span style="background-color:#F08080; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_CORAL("#F08080", "lightCoral"),

	/**
	 * HTML color name "<b>lightCyan</b>" - <span style="background-color:#E0FFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_CYAN("#E0FFFF", "lightCyan"),

	/**
	 * HTML color name "<b>lightGoldenRodYellow</b>" -
	 * <span style="background-color:#FAFAD2; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_GOLDEN_ROD_YELLOW("#FAFAD2", "lightGoldenRodYellow"),

	/**
	 * HTML color name "<b>lightGray</b>" - <span style="background-color:#D3D3D3; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_GRAY("#D3D3D3", "lightGray"),

	/**
	 * HTML color name "<b>lightGrey</b>" - <span style="background-color:#D3D3D3; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_GREY("#D3D3D3", "lightGrey"),

	/**
	 * HTML color name "<b>lightGreen</b>" - <span style="background-color:#90EE90; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_GREEN("#90EE90", "lightGreen"),

	/**
	 * HTML color name "<b>lightPink</b>" - <span style="background-color:#FFB6C1; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_PINK("#FFB6C1", "lightPink"),

	/**
	 * HTML color name "<b>lightSalmon</b>" - <span style="background-color:#FFA07A; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_SALMON("#FFA07A", "lightSalmon"),

	/**
	 * HTML color name "<b>lightSeaGreen</b>" - <span style="background-color:#20B2AA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_SEA_GREEN("#20B2AA", "lightSeaGreen"),

	/**
	 * HTML color name "<b>lightSkyBlue</b>" - <span style="background-color:#87CEFA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_SKY_BLUE("#87CEFA", "lightSkyBlue"),

	/**
	 * HTML color name "<b>lightSlateGray</b>" - <span style="background-color:#778899; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_SLATE_GRAY("#778899", "lightSlateGray"),

	/**
	 * HTML color name "<b>lightSlateGrey</b>" - <span style="background-color:#778899; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_SLATE_GREY("#778899", "lightSlateGrey"),

	/**
	 * HTML color name "<b>lightSteelBlue</b>" - <span style="background-color:#B0C4DE; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_STEEL_BLUE("#B0C4DE", "lightSteelBlue"),

	/**
	 * HTML color name "<b>lightYellow</b>" - <span style="background-color:#FFFFE0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_YELLOW("#FFFFE0", "lightYellow"),

	/**
	 * HTML color name "<b>lime</b>" - <span style="background-color:#00FF00; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIME("#00FF00", "lime"),

	/**
	 * HTML color name "<b>limeGreen</b>" - <span style="background-color:#32CD32; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIME_GREEN("#32CD32", "limeGreen"),

	/**
	 * HTML color name "<b>linen</b>" - <span style="background-color:#FAF0E6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LINEN("#FAF0E6", "linen"),

	/**
	 * HTML color name "<b>magenta</b>" - <span style="background-color:#FF00FF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MAGENTA("#FF00FF", "magenta"),

	/**
	 * HTML color name "<b>maroon</b>" - <span style="background-color:#800000; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MAROON("#800000", "maroon"),

	/**
	 * HTML color name "<b>mediumAquaMarine</b>" - <span style="background-color:#66CDAA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_AQUA_MARINE("#66CDAA", "mediumAquaMarine"),

	/**
	 * HTML color name "<b>mediumBlue</b>" - <span style="background-color:#0000CD; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_BLUE("#0000CD", "mediumBlue"),

	/**
	 * HTML color name "<b>mediumOrchid</b>" - <span style="background-color:#BA55D3; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_ORCHID("#BA55D3", "mediumOrchid"),

	/**
	 * HTML color name "<b>mediumPurple</b>" - <span style="background-color:#9370DB; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_PURPLE("#9370DB", "mediumPurple"),

	/**
	 * HTML color name "<b>mediumSeaGreen</b>" - <span style="background-color:#3CB371; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_SEA_GREEN("#3CB371", "mediumSeaGreen"),

	/**
	 * HTML color name "<b>mediumSlateBlue</b>" - <span style="background-color:#7B68EE; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_SLATE_BLUE("#7B68EE", "mediumSlateBlue"),

	/**
	 * HTML color name "<b>mediumSpringGreen</b>" -
	 * <span style="background-color:#00FA9A; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_SPRING_GREEN("#00FA9A", "mediumSpringGreen"),

	/**
	 * HTML color name "<b>mediumTurquoise</b>" - <span style="background-color:#48D1CC; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_TURQUOISE("#48D1CC", "mediumTurquoise"),

	/**
	 * HTML color name "<b>mediumVioletRed</b>" - <span style="background-color:#C71585; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEDIUM_VIOLET_RED("#C71585", "mediumVioletRed"),

	/**
	 * HTML color name "<b>midnightBlue</b>" - <span style="background-color:#191970; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MIDNIGHT_BLUE("#191970", "midnightBlue"),

	/**
	 * HTML color name "<b>mintCream</b>" - <span style="background-color:#F5FFFA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MINT_CREAM("#F5FFFA", "mintCream"),

	/**
	 * HTML color name "<b>mistyRose</b>" - <span style="background-color:#FFE4E1; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MISTY_ROSE("#FFE4E1", "mistyRose"),

	/**
	 * HTML color name "<b>moccasin</b>" - <span style="background-color:#FFE4B5; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOCCASIN("#FFE4B5", "moccasin"),

	/**
	 * HTML color name "<b>navajoWhite</b>" - <span style="background-color:#FFDEAD; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NAVAJO_WHITE("#FFDEAD", "navajoWhite"),

	/**
	 * HTML color name "<b>navy</b>" - <span style="background-color:#000080; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NAVY("#000080", "navy"),

	/**
	 * HTML color name "<b>oldLace</b>" - <span style="background-color:#FDF5E6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OLD_LACE("#FDF5E6", "oldLace"),

	/**
	 * HTML color name "<b>olive</b>" - <span style="background-color:#808000; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OLIVE("#808000", "olive"),

	/**
	 * HTML color name "<b>oliveDrab</b>" - <span style="background-color:#6B8E23; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OLIVE_DRAB("#6B8E23", "oliveDrab"),

	/**
	 * HTML color name "<b>orange</b>" - <span style="background-color:#FFA500; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ORANGE("#FFA500", "orange"),

	/**
	 * HTML color name "<b>orangeRed</b>" - <span style="background-color:#FF4500; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ORANGE_RED("#FF4500", "orangeRed"),

	/**
	 * HTML color name "<b>orchid</b>" - <span style="background-color:#DA70D6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ORCHID("#DA70D6", "orchid"),

	/**
	 * HTML color name "<b>paleGoldenRod</b>" - <span style="background-color:#EEE8AA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PALE_GOLDEN_ROD("#EEE8AA", "paleGoldenRod"),

	/**
	 * HTML color name "<b>paleGreen</b>" - <span style="background-color:#98FB98; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PALE_GREEN("#98FB98", "paleGreen"),

	/**
	 * HTML color name "<b>paleTurquoise</b>" - <span style="background-color:#AFEEEE; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PALE_TURQUOISE("#AFEEEE", "paleTurquoise"),

	/**
	 * HTML color name "<b>paleVioletRed</b>" - <span style="background-color:#DB7093; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PALE_VIOLET_RED("#DB7093", "paleVioletRed"),

	/**
	 * HTML color name "<b>papayaWhip</b>" - <span style="background-color:#FFEFD5; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PAPAYA_WHIP("#FFEFD5", "papayaWhip"),

	/**
	 * HTML color name "<b>peachPuff</b>" - <span style="background-color:#FFDAB9; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PEACH_PUFF("#FFDAB9", "peachPuff"),

	/**
	 * HTML color name "<b>peru</b>" - <span style="background-color:#CD853F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PERU("#CD853F", "peru"),

	/**
	 * HTML color name "<b>pink</b>" - <span style="background-color:#FFC0CB; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PINK("#FFC0CB", "pink"),

	/**
	 * HTML color name "<b>plum</b>" - <span style="background-color:#DDA0DD; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PLUM("#DDA0DD", "plum"),

	/**
	 * HTML color name "<b>powderBlue</b>" - <span style="background-color:#B0E0E6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	POWDER_BLUE("#B0E0E6", "powderBlue"),

	/**
	 * HTML color name "<b>purple</b>" - <span style="background-color:#800080; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE("#800080", "purple"),

	/**
	 * HTML color name "<b>rebeccaPurple</b>" - <span style="background-color:#663399; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	REBECCA_PURPLE("#663399", "rebeccaPurple"),

	/**
	 * HTML color name "<b>red</b>" - <span style="background-color:#FF0000; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RED("#FF0000", "red"),

	/**
	 * HTML color name "<b>rosyBrown</b>" - <span style="background-color:#BC8F8F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROSY_BROWN("#BC8F8F", "rosyBrown"),

	/**
	 * HTML color name "<b>royalBlue</b>" - <span style="background-color:#4169E1; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROYAL_BLUE("#4169E1", "royalBlue"),

	/**
	 * HTML color name "<b>saddleBrown</b>" - <span style="background-color:#8B4513; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SADDLE_BROWN("#8B4513", "saddleBrown"),

	/**
	 * HTML color name "<b>salmon</b>" - <span style="background-color:#FA8072; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SALMON("#FA8072", "salmon"),

	/**
	 * HTML color name "<b>sandyBrown</b>" - <span style="background-color:#F4A460; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SANDY_BROWN("#F4A460", "sandyBrown"),

	/**
	 * HTML color name "<b>seaGreen</b>" - <span style="background-color:#2E8B57; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEA_GREEN("#2E8B57", "seaGreen"),

	/**
	 * HTML color name "<b>seaShell</b>" - <span style="background-color:#FFF5EE; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEA_SHELL("#FFF5EE", "seaShell"),

	/**
	 * HTML color name "<b>sienna</b>" - <span style="background-color:#A0522D; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SIENNA("#A0522D", "sienna"),

	/**
	 * HTML color name "<b>silver</b>" - <span style="background-color:#C0C0C0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SILVER("#C0C0C0", "silver"),

	/**
	 * HTML color name "<b>skyBlue</b>" - <span style="background-color:#87CEEB; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SKY_BLUE("#87CEEB", "skyBlue"),

	/**
	 * HTML color name "<b>slateBlue</b>" - <span style="background-color:#6A5ACD; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SLATE_BLUE("#6A5ACD", "slateBlue"),

	/**
	 * HTML color name "<b>slateGray</b>" - <span style="background-color:#708090; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SLATE_GRAY("#708090", "slateGray"),

	/**
	 * HTML color name "<b>slateGrey</b>" - <span style="background-color:#708090; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SLATE_GREY("#708090", "slateGrey"),

	/**
	 * HTML color name "<b>snow</b>" - <span style="background-color:#FFFAFA; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SNOW("#FFFAFA", "snow"),

	/**
	 * HTML color name "<b>springGreen</b>" - <span style="background-color:#00FF7F; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SPRING_GREEN("#00FF7F", "springGreen"),

	/**
	 * HTML color name "<b>steelBlue</b>" - <span style="background-color:#4682B4; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	STEEL_BLUE("#4682B4", "steelBlue"),

	/**
	 * HTML color name "<b>tan</b>" - <span style="background-color:#D2B48C; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TAN("#D2B48C", "tan"),

	/**
	 * HTML color name "<b>teal</b>" - <span style="background-color:#008080; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TEAL("#008080", "teal"),

	/**
	 * HTML color name "<b>thistle</b>" - <span style="background-color:#D8BFD8; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	THISTLE("#D8BFD8", "thistle"),

	/**
	 * HTML color name "<b>tomato</b>" - <span style="background-color:#FF6347; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TOMATO("#FF6347", "tomato"),

	/**
	 * HTML color name "<b>turquoise</b>" - <span style="background-color:#40E0D0; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TURQUOISE("#40E0D0", "turquoise"),

	/**
	 * HTML color name "<b>violet</b>" - <span style="background-color:#EE82EE; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VIOLET("#EE82EE", "violet"),

	/**
	 * HTML color name "<b>wheat</b>" - <span style="background-color:#F5DEB3; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WHEAT("#F5DEB3", "wheat"),

	/**
	 * HTML color name "<b>white</b>" - <span style="background-color:#FFFFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WHITE("#FFFFFF", "white"),

	/**
	 * HTML color name "<b>whiteSmoke</b>" - <span style="background-color:#F5F5F5; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WHITE_SMOKE("#F5F5F5", "whiteSmoke"),

	/**
	 * HTML color name "<b>yellow</b>" - <span style="background-color:#FFFF00; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	YELLOW("#FFFF00", "yellow"),

	/**
	 * HTML color name "<b>yellowGreen</b>" - <span style="background-color:#9ACD32; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	YELLOW_GREEN("#9ACD32", "yellowGreen"),

	/**
	 * HTML color name "<b>transparent</b>" - <span style="background-color:#FFFFFF; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TRANSPARENT("#FFFFFF", "transparent", 0);

	// color instance
	private final IsColor color;
	// html color name
	private final String htmlColorName;

	/**
	 * Creates a color with HEX value.
	 * 
	 * @param hexValue color string representation in hex mode
	 * @param htmlColorName HTML color name of this color
	 */
	private HtmlColor(String hexValue, String htmlColorName) {
		this.color = ColorBuilder.buildByHexValue(hexValue, false);
		this.htmlColorName = htmlColorName;
	}

	/**
	 * Creates a color with HEX value.
	 * 
	 * @param hexValue color string representation in hex mode
	 * @param htmlColorName HTML color name of this color
	 * @param alpha the alpha to set
	 */
	private HtmlColor(String hexValue, String htmlColorName, double alpha) {
		IsColor internalColor = ColorBuilder.buildByHexValue(hexValue, false);
		this.color = internalColor.alpha(alpha);
		this.htmlColorName = htmlColorName;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.colors.IsEnumeratedColor#getColor()
	 */
	@Override
	public IsColor getColor() {
		return color;
	}

	/**
	 * Returns the HTML color name.
	 * 
	 * @return the HTML color name
	 */
	public String getHtmlColorName() {
		return htmlColorName;
	}
}
