/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.events;

import org.pepstock.charba.client.commons.Checker;
import org.pepstock.charba.client.enums.ChartEventProperty;
import org.pepstock.charba.client.items.SizeItem;

/**
 * Event which is fired when the chart has been resized.
 * 
 * @author Andrea "Stock" Stocchero
 */
public final class ChartResizeEvent extends AbstractChartEvent {

	/**
	 * Event type
	 */
	public static final EventType TYPE = EventType.create(ChartResizeEvent.class);
	// item which contains the new size of the chart
	private final SizeItem size;

	/**
	 * Creates the event with a item with new size of the chart
	 * 
	 * @param eventContext event context generated by CHART.js
	 * @param size item with the new size of the chart
	 */
	public ChartResizeEvent(ChartEventContext eventContext, SizeItem size) {
		super(eventContext, TYPE, ChartEventProperty.ON_RESIZE);
		// checks if argument is consistent
		this.size = Checker.checkAndGetIfValid(size, "Size argument");
	}

	/**
	 * Returns item with the new size of the chart
	 * 
	 * @return the item with the new size of the chart
	 */
	public SizeItem getSize() {
		return size;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.events.Event#dispatch(org.pepstock.charba.client.events.EventHandler)
	 */
	@Override
	protected void dispatch(EventHandler handler) {
		// checks if handler is a correct instance
		if (handler instanceof ChartResizeEventHandler) {
			// casts handler
			ChartResizeEventHandler myHandler = (ChartResizeEventHandler) handler;
			// invokes
			myHandler.onResize(this);
		}
	}

}